' Accelerometer variables
dim accelPWMPeriod 			as single


' readAccel reads acceleration data from the ADXL202eb
'	It first measures a PWM input on the specified pin.
'	It then converts it to a value based on the equations
'	in the chip's spec sheet.
'	The function returns a 7-bit midi data byte ranged appropriately.
function readAccel(byVal pin as byte) as byte
	dim accelValue as single
	dim accelByte as byte

	' Measure x-axis pulse width in seconds
	call pulseIn(pin, 1, accelValue)
	'debug.print "Original reading: "; cstr(accelValue)

	' Convert to us:
	accelValue = accelValue * 1000000.0
	'debug.print "In microseconds: "; cstr(accelValue)

	' calclate acceleration (equation from ADXL data sheet)
	' Empirically, this seems to yield a nominal value of around 4.5
	'	when the chip is motionless and level. The value will
	' 	vary +/- 2.0 reflecting tilt and acceleration
	accelValue = 8.0 * accelValue / accelPWMPeriod
	'debug.print "Converted: "; cstr(accelValue)

	' Range the single (aprox 2.5 - 6.5) to a 7-bit midi byte (0-127)
	accelByte = cByte(63.0 + (4.5 - accelValue) * 30.0)

	' return computed value
	readAccel = accelByte

end function
' End readAccel



' readAccelUI is a 16-bit version of the (7-bit) readAccel
'	It returns an unsigned integer.
'	Note some unusual syntax for an unsigned function.
function readAccelUI(byVal pin as byte) as unsignedInteger
	set readAccelUI = new unsignedinteger

	dim accelValue as single
	dim accelByte as byte

	' Measure x-axis pulse width in seconds
	call pulseIn(pin, 1, accelValue)

	accelValue = accelValue * 30000000.0
	readAccelUI = fixUI(accelValue)

end function
' End readAccel



' Determine the PWM period for the ADXL202eb
' This measurement will be used later to calculate
' X and Y acceleration
sub callibrateAccel(byVal pin as byte)

	dim count as long
	' Count the number of pulses that occur in 500 ms.
	' number of pulses = number of transitions / 2
	count = countTransitions(pin, 0.5)
	count = count \ 2

	' Calculate pulsewidth in microseconds
	accelPWMPeriod = 500000.0/(csng(count))

end sub
' End calibrateAccel
